{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": " ${ inputs.main_file.secondaryFiles = Array.isArray(inputs.secondary_files) ? inputs.secondary_files : [inputs.secondary_files];\nreturn { \"file_with_secondary_files\": inputs.main_file } } ",
            "doc": "Step to put secondary input files in the same folder as a main file",
            "inputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/main_file"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#combine_files.cwl/secondary_files"
                }
            ],
            "id": "#combine_files.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/file_with_secondary_files"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/bedtools"
                }
            ],
            "inputs": [
                {
                    "id": "#bedtools-intersect.cwl/b",
                    "type": "File",
                    "doc": "<bed/gff/vcf/bam>",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-b"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/a",
                    "type": "File",
                    "doc": "Input <bed/gff/vcf/bam> file",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wa",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original entry in A for each overlap.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wa"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wb",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original entry in B for each overlap.\n- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wb"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/loj",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Perform a \"left outer join\". That is, for each feature in A\nreport each overlap with B.  If no overlaps are found,\nreport a NULL feature for B.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-loj"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wo",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlaps restricted by -f and -r.\nOnly A features with overlap are reported.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wo"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wao",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlapping features restricted by -f and -r.\nHowever, A features w/o overlap are also reported\nwith a NULL B feature and overlap = 0.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wao"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/u",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A entry _once_ if _any_ overlaps found in B.\n- In other words, just report the fact >=1 hit was found.\n- Overlaps restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/c",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "For each entry in A, report the number of overlaps with B.\n- Reports 0 for A entries that have no overlap with B.\n- Overlaps restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/v",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Only report those entries in A that have _no overlaps_ with B.\n- Similar to \"grep -v\" (an homage).\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/ubam",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/s",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require same strandedness.  That is, only report hits in B\nthat overlap A on the _same_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/S",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require different strandedness.  That is, only report hits in B\nthat overlap A on the _opposite_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/f",
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Minimum overlap required as a fraction of A.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/F",
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Minimum overlap required as a fraction of B.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/r",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require that the fraction overlap be reciprocal for A AND B.\n- In other words, if -f is 0.90 and -r is used, this requires\nthat B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/e",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require that the minimum fraction be satisfied for A OR B.\n- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\nthat either 90 percent of A is covered OR 10 percent of  B is covered.\nWithout -e, both fractions would have to be satisfied.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/split",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Treat \"split\" BAM or BED12 entries as distinct BED intervals.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/g",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Provide a genome file to enforce consistent chromosome sort order\nacross input files. Only applies when used with -sorted option.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/nonamecheck",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "For sorted data, don't throw an error if the file has different naming conventions\nfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nonamecheck"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/sorted",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Use the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sorted"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/names",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, provide an alias for each that\nwill appear instead of a fileId when also printing the DB record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-names"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/filenames",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, show each complete filename\ninstead of a fileId when also printing the DB record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-filenames"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/sortout",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, sort the output DB hits\nfor each record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sortout"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/bed",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "If using BAM input, write output as BED.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/header",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Print the header from the A file prior to results.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-header"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/nobuf",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Disable buffered output. Using this option will cause each line\nof output to be printed as it is generated, rather than saved\nin a buffer. This will make printing large output files\nnoticeably slower, but can be useful in conjunction with\nother software tools and scripts that need to process one\nline of bedtools output at a time.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nobuf"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/iobuf",
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Specify amount of memory to use for input buffer.\nTakes an integer argument. Optional suffixes K/M/G supported.\nNote: currently has no effect with compressed files.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-iobuf"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/output",
                    "type": "string",
                    "default": "out.bed"
                }
            ],
            "outputs": [
                {
                    "id": "#bedtools-intersect.cwl/intersect_output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    }
                }
            ],
            "stdout": "$(inputs.output)",
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "doc": "Tool:    bedtools intersect (aka intersectBed)\nVersion: v2.25.0\nSummary: Report overlaps between two feature files.\n\nUsage:   bedtools intersect [OPTIONS] -a <bed/gff/vcf/bam> -b <bed/gff/vcf/bam>\n\n\tNote: -b may be followed with multiple databases and/or \n\twildcard (*) character(s). \nOptions: \n\t-wa\tWrite the original entry in A for each overlap.\n\n\t-wb\tWrite the original entry in B for each overlap.\n\t\t- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n\n\t-loj\tPerform a \"left outer join\". That is, for each feature in A\n\t\treport each overlap with B.  If no overlaps are found, \n\t\treport a NULL feature for B.\n\n\t-wo\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlaps restricted by -f and -r.\n\t\t  Only A features with overlap are reported.\n\n\t-wao\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlapping features restricted by -f and -r.\n\t\t  However, A features w/o overlap are also reported\n\t\t  with a NULL B feature and overlap = 0.\n\n\t-u\tWrite the original A entry _once_ if _any_ overlaps found in B.\n\t\t- In other words, just report the fact >=1 hit was found.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-c\tFor each entry in A, report the number of overlaps with B.\n\t\t- Reports 0 for A entries that have no overlap with B.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-v\tOnly report those entries in A that have _no overlaps_ with B.\n\t\t- Similar to \"grep -v\" (an homage).\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n\t-s\tRequire same strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _same_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-S\tRequire different strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _opposite_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-f\tMinimum overlap required as a fraction of A.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-F\tMinimum overlap required as a fraction of B.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-r\tRequire that the fraction overlap be reciprocal for A AND B.\n\t\t- In other words, if -f is 0.90 and -r is used, this requires\n\t\t  that B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n\n\t-e\tRequire that the minimum fraction be satisfied for A OR B.\n\t\t- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\n\t\t  that either 90 percent of A is covered OR 10 percent of  B is covered.\n\t\t  Without -e, both fractions would have to be satisfied.\n\n\t-split\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\n\t-g\tProvide a genome file to enforce consistent chromosome sort order\n\t\tacross input files. Only applies when used with -sorted option.\n\n\t-nonamecheck\tFor sorted data, don't throw an error if the file has different naming conventions\n\t\t\tfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n\n\t-sorted\tUse the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n\n\t-names\tWhen using multiple databases, provide an alias for each that\n\t\twill appear instead of a fileId when also printing the DB record.\n\n\t-filenames\tWhen using multiple databases, show each complete filename\n\t\t\tinstead of a fileId when also printing the DB record.\n\n\t-sortout\tWhen using multiple databases, sort the output DB hits\n\t\t\tfor each record.\n\n\t-bed\tIf using BAM input, write output as BED.\n\n\t-header\tPrint the header from the A file prior to results.\n\n\t-nobuf\tDisable buffered output. Using this option will cause each line\n\t\tof output to be printed as it is generated, rather than saved\n\t\tin a buffer. This will make printing large output files \n\t\tnoticeably slower, but can be useful in conjunction with\n\t\tother software tools and scripts that need to process one\n\t\tline of bedtools output at a time.\n\n\t-iobuf\tSpecify amount of memory to use for input buffer.\n\t\tTakes an integer argument. Optional suffixes K/M/G supported.\n\t\tNote: currently has no effect with compressed files.\n\nNotes: \n\t(1) When a BAM file is used for the A file, the alignment is retained if overlaps exist,\n\tand exlcuded if an overlap cannot be found.  If multiple overlaps exist, they are not\n\treported, as we are only testing for one or more overlaps.",
            "id": "#bedtools-intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/dict_to_interval_list.py"
            ],
            "hints": [
                {
                    "dockerPull": "mercury/dict-to-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                {
                    "prefix": "--output_dir",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "id": "#dict_to_interval_list.cwl/dictionary",
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--path",
                        "itemSeparator": " "
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#dict_to_interval_list.cwl/interval_list",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.interval_list"
                    }
                }
            ],
            "id": "#dict_to_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c"
            ],
            "requirements": [
                {
                    "dockerPull": "ubuntu:14.04",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                "cat \"$(inputs.interval_list.path)\" | awk  'BEGIN {\n  FS=\"\\\\t\";\n} /^@/ || $1~/$(inputs.chromosome_regex)/ {\n  print;\n}' > $(inputs.output_filename)\n"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_interval_list.cwl/chromosome_regex"
                },
                {
                    "type": "File",
                    "id": "#filter_interval_list.cwl/interval_list"
                },
                {
                    "default": "filtered_interval_list.interval_list",
                    "type": "string",
                    "id": "#filter_interval_list.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#filter_interval_list.cwl/output"
                }
            ],
            "id": "#filter_interval_list.cwl"
        },
        {
            "id": "#HaplotypeCaller.cwl",
            "baseCommand": [
                "python3",
                "/gatk-local-io-wrapper.py",
                "[]",
                "[]",
                "[\"-XX:MaxRAMFraction=1\",\"-XX:+UnlockExperimentalVMOptions\",\"-XX:+UseCGroupMemoryLimitForHeap\"]",
                "HaplotypeCaller"
            ],
            "class": "CommandLineTool",
            "doc": "Call germline SNPs and indels via local re-assembly of haplotypes\n\n <p>The HaplotypeCaller is capable of calling SNPs and indels simultaneously via local de-novo assembly of haplotypes in an active region. In other words, whenever the program encounters a region showing signs of variation, it discards the existing mapping information and completely reassembles the reads in that region. This allows the HaplotypeCaller to be more accurate when calling regions that are traditionally difficult to call, for example when they contain different types of variants close to each other. It also makes the HaplotypeCaller much better at calling indels than position-based callers like UnifiedGenotyper.</p>\n\n <p>In the GVCF workflow used for scalable variant calling in DNA sequence data, HaplotypeCaller runs per-sample to generate an intermediate GVCF (not to be used in final analysis), which can then be used in GenotypeGVCFs for joint genotyping of multiple samples in a very efficient way. The GVCF workflow enables rapid incremental processing of samples as they roll off the sequencer, as well as scaling to very large cohort sizes (e.g. the 92K exomes of ExAC).</p>\n\n <p>In addition, HaplotypeCaller is able to handle non-diploid organisms as well as pooled experiment data. Note however that the algorithms used to calculate variant likelihoods is not well suited to extreme allele frequencies (relative to ploidy) so its use is not recommended for somatic (cancer) variant discovery. For that purpose, use Mutect2 instead.</p>\n\n <p>Finally, HaplotypeCaller is also able to correctly handle the splice junctions that make RNAseq a challenge for most variant callers,\n on the condition that the input read data has previously been processed according to our recommendations as documented <a href='https://software.broadinstitute.org/gatk/documentation/article?id=4067'>here</a>.</p>\n\n <h3>How HaplotypeCaller works</h3>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4147'>1. Define active regions </a></h4>\n\n <p>The program determines which regions of the genome it needs to operate on (active regions), based on the presence of\n evidence for variation.\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4146'>2. Determine haplotypes by assembly of the active region </a></h4>\n\n <p>For each active region, the program builds a De Bruijn-like graph to reassemble the active region and identifies\n what are the possible haplotypes present in the data. The program then realigns each haplotype against the reference\n haplotype using the Smith-Waterman algorithm in order to identify potentially variant sites. </p>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4441'>3. Determine likelihoods of the haplotypes given the read data </a></h4>\n\n <p>For each active region, the program performs a pairwise alignment of each read against each haplotype using the\n PairHMM algorithm. This produces a matrix of likelihoods of haplotypes given the read data. These likelihoods are\n then marginalized to obtain the likelihoods of alleles for each potentially variant site given the read data.   </p>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4442'>4. Assign sample genotypes </a></h4>\n\n <p>For each potentially variant site, the program applies Bayes' rule, using the likelihoods of alleles given the\n read data to calculate the likelihoods of each genotype per sample given the read data observed for that\n sample. The most likely genotype is then assigned to the sample.    </p>\n\n <h3>Input</h3>\n <p>\n Input bam file(s) from which to make variant calls\n </p>\n\n <h3>Output</h3>\n <p>\n Either a VCF or GVCF file with raw, unfiltered SNP and indel calls. Regular VCFs must be filtered either by variant\n recalibration (Best Practice) or hard-filtering before use in downstream analyses. If using the GVCF workflow, the\n output is a GVCF file that must first be run through GenotypeGVCFs and then filtering before further analysis.\n </p>\n\n <h3>Usage examples</h3>\n\n <p>These are example commands that show how to run HaplotypeCaller for typical use cases. Have a look at the <a href='https://software.broadinstitute.org/gatk/documentation/article?id=3893'>method documentation</a> for the basic GVCF workflow. </p>\n\n <br />\n <h4>Single-sample GVCF calling (outputs intermediate GVCF)</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF\n </pre>\n\n <h4>Single-sample GVCF calling with <a href='https://software.broadinstitute.org/gatk/documentation/article?id=9622'>allele-specific annotations</a></h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF \\\n   -G Standard \\\n   -G AS_Standard\n </pre>\n\n <h4>Variant calling with <a href='https://software.broadinstitute.org/gatk/documentation/article?id=5484'>bamout</a> to show realigned reads</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.vcf.gz \\\n   -bamout bamout.bam\n </pre>\n\n <h3>Caveats</h3>\n <ul>\n <li>We have not yet fully tested the interaction between the GVCF-based calling or the multisample calling and the\n RNAseq-specific functionalities. Use those in combination at your own risk.</li>\n </ul>\n\n <h3>Special note on ploidy</h3>\n <p>This tool is able to handle many non-diploid use cases; the desired ploidy can be specified using the -ploidy\n argument. Note however that very high ploidies (such as are encountered in large pooled experiments) may cause\n performance challenges including excessive slowness. We are working on resolving these limitations.</p>\n\n <h3>Additional Notes</h3>\n <ul>\n     <li>When working with PCR-free data, be sure to set `-pcr_indel_model NONE` (see argument below).</li>\n     <li>When running in `-ERC GVCF` or `-ERC BP_RESOLUTION` modes, the confidence threshold\n     is automatically set to 0. This cannot be overridden by the command line. The threshold can be set manually\n     to the desired level in the next step of the workflow (GenotypeGVCFs)</li>\n     <li>We recommend using a list of intervals to speed up analysis. See <a href='https://software.broadinstitute.org/gatk/documentation/article?id=4133'>this document</a> for details.</li>\n </ul>",
            "temporaryFailCodes": [
                3
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element, prefix);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self, prefix);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-local-io-wrapper:v4"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/reference",
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input",
                    "type": [
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "Minimum probability for a locus to be considered active.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/active-probability-threshold",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--active-probability-threshold"
                    }
                },
                {
                    "doc": "Output the raw activity profile results in IGV format",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/activity-profile-out-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--activity-profile-out"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Annotate all sites with PLs",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/all-site-pls",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--all-site-pls",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The set of alleles at which to genotype when --genotyping_mode is GENOTYPE_GIVEN_ALLELES",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/alleles",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--alleles\", inputs['alleles_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'alleles'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/alleles_tags"
                },
                {
                    "doc": "Allow graphs that have non-unique kmers in the reference",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/allow-non-unique-kmers-in-ref",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--allow-non-unique-kmers-in-ref",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotate-with-num-discovered-alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--annotate-with-num-discovered-alleles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more specific annotations to add to variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotation",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation\"))"
                    }
                },
                {
                    "doc": "One or more groups of annotations to apply to variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotation-group",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation-group\"))"
                    }
                },
                {
                    "doc": "One or more specific annotations to exclude from variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotations-to-exclude",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotations-to-exclude\"))"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/arguments_file_tags"
                },
                {
                    "doc": "Output the assembly region to this IGV formatted file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-out-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--assembly-region-out"
                    }
                },
                {
                    "doc": "Number of additional bases of context to include around each assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--assembly-region-padding"
                    }
                },
                {
                    "doc": "File to which assembled haplotypes should be written",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-output-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--bam-output"
                    }
                },
                {
                    "doc": "Which haplotypes should be written to the BAM",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type/ALL_POSSIBLE_HAPLOTYPES",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type/CALLED_HAPLOTYPES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--bam-writer-type"
                    }
                },
                {
                    "doc": "Base qualities below this threshold will be reduced to the minimum (6)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/base-quality-score-threshold",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--base-quality-score-threshold"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "Comparison VCF file(s)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/comp",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--comp\", inputs['comp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'comp'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/comp_tags"
                },
                {
                    "doc": "1000G consensus mode",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/consensus",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--consensus",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Tab-separated File containing fraction of contamination in sequencing data (per sample) to aggressively remove. Format should be \"<SampleID><TAB><Contamination>\" (Contamination is double) per line; No header.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-per-sample-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--contamination-fraction-per-sample-file\", inputs['contamination-fraction-per-sample-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'contamination-fraction-per-sample-file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-per-sample-file_tags"
                },
                {
                    "doc": "Fraction of contamination in sequencing data (for all samples) to aggressively remove",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-to-filter",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--contamination-fraction-to-filter"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "dbSNP file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dbsnp",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--dbsnp\", inputs['dbsnp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'dbsnp'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dbsnp_tags"
                },
                {
                    "doc": "Print out very verbose debug information about each triggering active region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--debug",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Don't skip calculations in ActiveRegions with no variants",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-optimizations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-optimizations",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable physical phasing",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/do-not-run-physical-phasing",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--do-not-run-physical-phasing",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable iterating over kmer sizes when graph cycles are detected",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-increase-kmer-sizes-for-cycles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-increase-kmer-sizes-for-cycles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If specified, we will not trim down the active region from the full region (active + extension) to just the active interval for genotyping",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-trim-active-regions",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-trim-active-regions",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Do not analyze soft clipped bases in the reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-use-soft-clipped-bases",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-use-soft-clipped-bases",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Mode for emitting reference confidence scores",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/NONE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/BP_RESOLUTION",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/GVCF"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--emit-ref-confidence"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Specifies how to determine the alternate alleles to use for genotyping",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode/DISCOVERY",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode/GENOTYPE_GIVEN_ALLELES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--genotyping-mode"
                    }
                },
                {
                    "doc": "Write debug assembly graph information to this file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/graph-output-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--graph-output"
                    }
                },
                {
                    "doc": "Exclusive upper bounds for reference confidence GQ bands (must be in [1, 100] and specified in increasing order)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gvcf-gq-bands",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "int"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--gvcf-gq-bands\"))"
                    }
                },
                {
                    "doc": "Heterozygosity value used to compute prior likelihoods for any locus.  See the GATKDocs for full details on the meaning of this population genetics concept",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity"
                    }
                },
                {
                    "doc": "Standard deviation of eterozygosity for SNP and indel calling.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/heterozygosity-stdev",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity-stdev"
                    }
                },
                {
                    "doc": "Heterozygosity for indel calling.  See the GATKDocs for heterozygosity for full details on the meaning of this population genetics concept",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/indel-heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-heterozygosity"
                    }
                },
                {
                    "doc": "The size of an indel to check for in the reference model",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/indel-size-to-eliminate-in-ref-model",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-size-to-eliminate-in-ref-model"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input_tags"
                },
                {
                    "doc": "Input prior for calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input-prior",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "double",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "double"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--input-prior\"))"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule/ALL",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule/UNION",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ],
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/intervals_tags"
                },
                {
                    "doc": "Kmer size to use in the read threading assembler",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/kmer-size",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "int"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--kmer-size\"))"
                    }
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Maximum number of alternate alleles to genotype",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-alternate-alleles",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-alternate-alleles"
                    }
                },
                {
                    "doc": "Maximum size of an assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-assembly-region-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-assembly-region-size"
                    }
                },
                {
                    "doc": "Maximum number of genotypes to consider at any site",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-genotype-count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-genotype-count"
                    }
                },
                {
                    "doc": "Maximum number of haplotypes to consider for your population",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-num-haplotypes-in-population",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-num-haplotypes-in-population"
                    }
                },
                {
                    "doc": "Upper limit on how many bases away probability mass can be moved around when calculating the boundaries between active and inactive assembly regions",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-prob-propagation-distance",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-prob-propagation-distance"
                    }
                },
                {
                    "doc": "Maximum number of reads to retain per alignment start position. Reads above this threshold will be downsampled. Set to 0 to disable.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-reads-per-alignment-start",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-reads-per-alignment-start"
                    }
                },
                {
                    "doc": "Minimum size of an assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-assembly-region-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-assembly-region-size"
                    }
                },
                {
                    "doc": "Minimum base quality required to consider a base for calling",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-base-quality-score",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-base-quality-score"
                    }
                },
                {
                    "doc": "Minimum length of a dangling branch to attempt recovery",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-dangling-branch-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-dangling-branch-length"
                    }
                },
                {
                    "doc": "Minimum support to not prune paths in the graph",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-pruning",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-pruning"
                    }
                },
                {
                    "doc": "How many threads should a native pairHMM implementation use",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/native-pair-hmm-threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--native-pair-hmm-threads"
                    }
                },
                {
                    "doc": "use double precision in the native pairHmm. This is slower but matches the java implementation better",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/native-pair-hmm-use-double-precision",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--native-pair-hmm-use-double-precision",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Number of samples that must pass the minPruning threshold",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/num-pruning-samples",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--num-pruning-samples"
                    }
                },
                {
                    "doc": "File to which variants should be written",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output-filename",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    }
                },
                {
                    "doc": "Specifies which type of calls we should output",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_VARIANTS_ONLY",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_ALL_CONFIDENT_SITES",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_ALL_SITES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--output-mode"
                    }
                },
                {
                    "doc": "Flat gap continuation penalty for use in the Pair HMM",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/pair-hmm-gap-continuation-penalty",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--pair-hmm-gap-continuation-penalty"
                    }
                },
                {
                    "doc": "The PCR indel model to use",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/NONE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/HOSTILE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/AGGRESSIVE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/CONSERVATIVE"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--pcr-indel-model"
                    }
                },
                {
                    "doc": "The global assumed mismapping rate for reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/phred-scaled-global-read-mismapping-rate",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--phred-scaled-global-read-mismapping-rate"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/STRICT",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/LENIENT",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "doc": "This argument is deprecated since version 3.3",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/recover-dangling-heads",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--recover-dangling-heads",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/reference_tags"
                },
                {
                    "doc": "Name of single sample to use from a multi-sample bam",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-name"
                    }
                },
                {
                    "doc": "Ploidy (number of chromosomes) per sample. For pooled data, set to (Number of samples in each pool * Sample Ploidy).",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample-ploidy",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-ploidy"
                    }
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Which Smith-Waterman implementation to use, generally FASTEST_AVAILABLE is the right choice",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/FASTEST_AVAILABLE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/AVX_ENABLED",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/JAVA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--smith-waterman"
                    }
                },
                {
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/standard-min-confidence-threshold-for-calling",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--standard-min-confidence-threshold-for-calling"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/TMP_DIR_tags"
                },
                {
                    "doc": "Use additional trigger on variants found in an external alleles file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-alleles-trigger",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-alleles-trigger",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Use the contamination-filtered read maps for the purposes of annotating variants",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-filtered-reads-for-annotations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-filtered-reads-for-annotations",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-new-qual-calculator",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/ERROR",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/WARNING",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/INFO",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/activity-profile-out",
                    "doc": "Output file from corresponding to the input argument activity-profile-out-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['activity-profile-out-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-out",
                    "doc": "Output file from corresponding to the input argument assembly-region-out-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['assembly-region-out-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-output",
                    "doc": "Output file from corresponding to the input argument bam-output-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['bam-output-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-index",
                    "doc": "index file generated if create-output-bam-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-md5",
                    "doc": "md5 file generated if create-output-bam-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/variant-index",
                    "doc": "index file generated if create-output-variant-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/variant-md5",
                    "doc": "md5 file generated if create-output-variant-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/graph-output",
                    "doc": "Output file from corresponding to the input argument graph-output-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['graph-output-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output",
                    "doc": "Output file from corresponding to the input argument output-filename",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output-filename'])"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/bed-to-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/bed_to_il.py"
            ],
            "inputs": [
                {
                    "id": "#bed_to_interval_list.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    }
                },
                {
                    "id": "#bed_to_interval_list.cwl/header",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--header"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#bed_to_interval_list.cwl/interval_list",
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bed"
                    }
                }
            ],
            "id": "#bed_to_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/interval-list-to-bed:v1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/il_to_bed.py"
            ],
            "inputs": [
                {
                    "id": "#interval_list_to_bed.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#interval_list_to_bed.cwl/bed_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bed"
                    }
                },
                {
                    "id": "#interval_list_to_bed.cwl/header",
                    "type": "File",
                    "outputBinding": {
                        "glob": "header.txt"
                    }
                }
            ],
            "id": "#interval_list_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/split_interval_list.py"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "mercury/split-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#split_interval_list.cwl/number_of_intervals",
                    "type": "int",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chunks"
                    }
                },
                {
                    "id": "#split_interval_list.cwl/interval_list",
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--path"
                    }
                }
            ],
            "arguments": [
                {
                    "prefix": "--output_dir",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "outputs": [
                {
                    "id": "#split_interval_list.cwl/interval_lists",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.*_of_*.interval_list",
                        "outputEval": "${\n  var files={};\n  var output=[];\n  var re = /^.*[.]([0-9]+)_of_[0-9]+[.]interval_list$/;\n  if (self.length == 0) {\n    return output;\n  }\n  for (var i = 0; i < self.length; ++i) {\n    var fn = self[i].basename\n    var result = re.exec(fn);\n    if (result === null) {\n      throw new Error(\"Unexpected filename in output \" + fn);\n    } else {\n      var index = result[1];\n    }\n    files[index] = self[i];\n  }\n  var sorted_indices = Object.keys(files);\n  sorted_indices.sort(function(a,b){return parseInt(a) - parseInt(b);});\n  for (var i = 0; i < sorted_indices.length; ++i) {\n   index = sorted_indices[i];\n    output.push(files[index]);\n  }\n  return output;\n}\n"
                    }
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/library_cram",
                    "type": "File"
                },
                {
                    "id": "#main/chunks",
                    "type": "int"
                },
                {
                    "id": "#main/intersect_file",
                    "type": "File"
                },
                {
                    "id": "#main/reference_dict",
                    "type": "File"
                },
                {
                    "id": "#main/reference_fasta",
                    "type": "File"
                },
                {
                    "id": "#main/ploidy",
                    "type": "int"
                },
                {
                    "id": "#main/include_chromosome_regex",
                    "type": "string",
                    "default": "."
                },
                {
                    "id": "#main/pcr_free",
                    "type": "boolean",
                    "default": true
                }
            ],
            "steps": [
                {
                    "id": "#main/dict_to_interval_list",
                    "run": "#dict_to_interval_list.cwl",
                    "in": [
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/dict_to_interval_list/dictionary"
                        }
                    ],
                    "out": [
                        "#main/dict_to_interval_list/interval_list"
                    ]
                },
                {
                    "id": "#main/intersect",
                    "run": "#intersect_intervals.cwl",
                    "in": [
                        {
                            "source": "#main/intersect_file",
                            "id": "#main/intersect/interval_list_A"
                        },
                        {
                            "source": "#main/dict_to_interval_list/interval_list",
                            "id": "#main/intersect/interval_list_B"
                        }
                    ],
                    "out": [
                        "#main/intersect/intersected_interval_list"
                    ]
                },
                {
                    "id": "#main/filter_interval_list",
                    "run": "#filter_interval_list.cwl",
                    "in": [
                        {
                            "source": "#main/include_chromosome_regex",
                            "id": "#main/filter_interval_list/chromosome_regex"
                        },
                        {
                            "source": "#main/intersect/intersected_interval_list",
                            "id": "#main/filter_interval_list/interval_list"
                        }
                    ],
                    "out": [
                        "#main/filter_interval_list/output"
                    ]
                },
                {
                    "id": "#main/split_interval_list",
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#main/filter_interval_list/output",
                            "id": "#main/split_interval_list/interval_list"
                        },
                        {
                            "source": "#main/chunks",
                            "id": "#main/split_interval_list/number_of_intervals"
                        }
                    ],
                    "out": [
                        "#main/split_interval_list/interval_lists"
                    ]
                },
                {
                    "id": "#main/haplotype_caller",
                    "scatter": [
                        "#main/haplotype_caller/intervals"
                    ],
                    "hints": [
                        {
                            "ramMin": 6000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "run": "#HaplotypeCaller.cwl",
                    "in": [
                        {
                            "valueFrom": "$( false )",
                            "id": "#main/haplotype_caller/add-output-vcf-command-line"
                        },
                        {
                            "valueFrom": "$([\"DepthPerAlleleBySample\",\"StrandBiasBySample\"])",
                            "id": "#main/haplotype_caller/annotation"
                        },
                        {
                            "valueFrom": "$( true )",
                            "id": "#main/haplotype_caller/create-output-variant-index"
                        },
                        {
                            "valueFrom": "$( true )",
                            "id": "#main/haplotype_caller/create-output-variant-md5"
                        },
                        {
                            "valueFrom": "GVCF",
                            "id": "#main/haplotype_caller/emit-ref-confidence"
                        },
                        {
                            "source": "#main/library_cram",
                            "id": "#main/haplotype_caller/input"
                        },
                        {
                            "source": "#main/split_interval_list/interval_lists",
                            "id": "#main/haplotype_caller/intervals"
                        },
                        {
                            "valueFrom": "$(inputs.input.nameroot)_$(inputs.intervals.nameroot).g.vcf.gz",
                            "id": "#main/haplotype_caller/output-filename"
                        },
                        {
                            "source": "#main/pcr_free",
                            "valueFrom": "${ if(self) { return \"NONE\" } else { return \"CONSERVATIVE\" }}",
                            "id": "#main/haplotype_caller/pcr-indel-model"
                        },
                        {
                            "source": "#main/reference_fasta",
                            "id": "#main/haplotype_caller/reference"
                        },
                        {
                            "source": "#main/ploidy",
                            "id": "#main/haplotype_caller/sample-ploidy"
                        },
                        {
                            "valueFrom": "INFO",
                            "id": "#main/haplotype_caller/verbosity"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/output",
                        "#main/haplotype_caller/variant-index",
                        "#main/haplotype_caller/variant-md5"
                    ]
                },
                {
                    "id": "#main/combine_haplotype_index",
                    "scatter": [
                        "#main/combine_haplotype_index/main_file",
                        "#main/combine_haplotype_index/secondary_files"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/haplotype_caller/output",
                            "id": "#main/combine_haplotype_index/main_file"
                        },
                        {
                            "source": "#main/haplotype_caller/variant-index",
                            "id": "#main/combine_haplotype_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#main/combine_haplotype_index/file_with_secondary_files"
                    ],
                    "run": "#combine_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#main/gvcf_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/combine_haplotype_index/file_with_secondary_files"
                },
                {
                    "id": "#main/intervals",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/split_interval_list/interval_lists"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "id": "#intersect_intervals.cwl/interval_list_A",
                    "type": "File"
                },
                {
                    "id": "#intersect_intervals.cwl/interval_list_B",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#intersect_intervals.cwl/interval_list_to_bed_A",
                    "run": "#interval_list_to_bed.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_A",
                            "id": "#intersect_intervals.cwl/interval_list_to_bed_A/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/interval_list_to_bed_A/bed_file",
                        "#intersect_intervals.cwl/interval_list_to_bed_A/header"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/interval_list_to_bed_B",
                    "run": "#interval_list_to_bed.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_B",
                            "id": "#intersect_intervals.cwl/interval_list_to_bed_B/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/interval_list_to_bed_B/bed_file",
                        "#intersect_intervals.cwl/interval_list_to_bed_B/header"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/intersect",
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_A/bed_file",
                            "id": "#intersect_intervals.cwl/intersect/a"
                        },
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_B/bed_file",
                            "id": "#intersect_intervals.cwl/intersect/b"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/intersect/intersect_output"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/bed_to_interval_list",
                    "run": "#bed_to_interval_list.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_A/header",
                            "id": "#intersect_intervals.cwl/bed_to_interval_list/header"
                        },
                        {
                            "source": "#intersect_intervals.cwl/intersect/intersect_output",
                            "id": "#intersect_intervals.cwl/bed_to_interval_list/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/bed_to_interval_list/interval_list"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#intersect_intervals.cwl/intersected_interval_list",
                    "type": "File",
                    "outputSource": "#intersect_intervals.cwl/bed_to_interval_list/interval_list"
                }
            ],
            "id": "#intersect_intervals.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
